/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.beans;

import java.beans.BeanDescriptor;
import java.io.Serializable;

/**
 * A serializable version of {@link java.beans.BeanDescriptor}.
 *
 * @author <a href="http://craigsdickson.com">Craig S. Dickson</a>
 */
public class RemoteBeanDescriptor implements Serializable {

    private static final long serialVersionUID = -8862959502695837518L;
    private String beanClass;

    /**
     * Creates a new RemoteBeanDescriptor object.
     *
     * @param bd the local BeanDescriptor object that this remote version should be based on
     */
    public RemoteBeanDescriptor(BeanDescriptor bd) {
        super();
        beanClass = bd.getBeanClass().getName();
    }

    /**
     * Accessor to the FQCN of the bean class.
     *
     * @return the name of the bean class
     */
    public String getBeanClass() {
        return beanClass;
    }
}
