/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.datatypes;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import com.squeakysand.commons.lang.ToStringHelper;

/**
 * EmailAddress Business Entity Object. Contains all information pertaining to a user's email address.
 */
public class EmailAddress {

    private static final String EMAIL_REGEX =
        "^[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\\.)+(?:[A-Z]{2}|com|org|net|edu|gov|mil|biz|info|mobi|name|aero|asia|jobs|museum)$";
    private static final Pattern EMAIL_REGEX_PATTERN = Pattern.compile(EMAIL_REGEX);
    private String emailAddress;

    /**
     * Default constructor.
     */
    public EmailAddress() {
    }

    /**
     * Constructor accepts String emailAddres as parameter.
     *
     * @param   emailAddress  Email address of the user
     * @throws  com.squeakysand.commons.datatypes.InvalidEmailAddressException  DOCUMENT ME!
     */
    public EmailAddress(String emailAddress) throws InvalidEmailAddressException {
        setEmailAddress(emailAddress);
    }

    /**
     * This method validates email Address. If address is not valid then throws InvalidEmailAddressException
     *
     * @param   email  email address
     * @return  boolean True or false, for validity of Email address
     * @throws  com.squeakysand.commons.datatypes.InvalidEmailAddressException  This method validates email Address. If address is not valid then throws
     *                                        com.squeakysand.commons.datatypes.InvalidEmailAddressException
     */
    public static boolean validate(String email) throws InvalidEmailAddressException {
        Matcher m = EMAIL_REGEX_PATTERN.matcher(email);
        return m.matches();
    }

    /**
     * Returns email address.
     *
     * @return  Email address of the user
     */
    public String getEmailAddress() {
        return emailAddress;
    }

    /**
     * Sets email address.
     *
     * @param   emailAddress  Email address of the user
     * @throws  com.squeakysand.commons.datatypes.InvalidEmailAddressException  DOCUMENT ME!
     */
    public void setEmailAddress(String emailAddress) throws InvalidEmailAddressException {
        if (validate(emailAddress)) {
            this.emailAddress = emailAddress;
        }
    }

    /**
     * {@inheritDoc}
     *
     * Returns a string representation of the object.
     */
    @Override
    public String toString() {
        return ToStringHelper.toString(this);
    }
}
