/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.datatypes;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * DOCUMENT ME!
 *
 * @author  <a href="mailto:craig@squeakysand.com">Craig S. Dickson</a>
 */
public class ZipCode {

    private static final String ZIP_CODE_REGEX = "^[0-9]{5}(-[0-9]{4})?$";
    private static final Pattern ZIP_CODE_REGEX_PATTERN = Pattern.compile(ZIP_CODE_REGEX);

    private String code;

    /**
     * Creates a new ZipCode object.
     *
     * @param   code  DOCUMENT ME!
     * @throws  java.lang.IllegalArgumentException  DOCUMENT ME!
     */
    public ZipCode(String code) {
        if (validate(code)) {
            this.code = code;
        } else {
            throw new IllegalArgumentException('"' + code + "\" is not a valid ZipCode");
        }
    }

    /**
     * DOCUMENT ME!
     *
     * @param   code  DOCUMENT ME!
     * @return  DOCUMENT ME!
     */
    public static boolean validate(String code) {
        Matcher m = ZIP_CODE_REGEX_PATTERN.matcher(code);
        return m.matches();
    }

    /**
     * DOCUMENT ME!
     *
     * @return  DOCUMENT ME!
     */
    public String get5DigitCode() {
        return code.substring(0, 5);
    }

    /**
     * <p>Getter for the field <code>code</code>.</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public String getCode() {
        return code;
    }

    /**
     * <p>getPlus4Code.</p>
     *
     * @return a {@link java.lang.String} object.
     */
    public String getPlus4Code() {
        String result = null;
        int dashIndex = code.indexOf('-');
        if (dashIndex != -1) {
            result = code.substring(dashIndex);
        }
        return result;
    }
}
