/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.io;

import java.io.File;
import java.io.IOException;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import com.squeakysand.commons.lang.ToStringHelper;

import org.apache.commons.io.DirectoryWalker;
import org.apache.commons.io.filefilter.IOFileFilter;
import org.apache.commons.io.filefilter.TrueFileFilter;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class FileFinder extends DirectoryWalker<File> {

    private static final Logger LOG = LoggerFactory.getLogger(FileFinder.class);

    public FileFinder(IOFileFilter filter) {
        super(TrueFileFilter.INSTANCE, filter, -1);
    }

    public List<File> findFiles(File directory) throws IOException {
        LOG.debug("processing directory {}", ToStringHelper.toString(directory));
        List<File> result = new ArrayList<File>();
        walk(directory, result);
        return result;
    }

    @Override
    protected void handleFile(File file, int depth, Collection<File> results) throws IOException {
        LOG.debug("found file {}", ToStringHelper.toString(file));
        results.add(file);
    }
}
