/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.io;

import java.io.File;
import java.io.FileFilter;
import java.util.regex.Pattern;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Implements the {@link java.io.FileFilter} interface and allows filtering based on a regular expression.
 */
public class PatternFileFilter implements FileFilter {

    private static final Logger LOG = LoggerFactory.getLogger(PatternFileFilter.class);

    private Pattern pattern;

    /**
     * Creates a new PatternFilenameFilter object.
     *
     * @param  pattern  the pattern to match filenames against.
     */
    public PatternFileFilter(Pattern pattern) {
        this.pattern = pattern;
        LOG.debug("pattern: {}", pattern.pattern());
    }

    /**
     * Creates a new PatternFilenameFilter object.
     *
     * @param  pattern  the regular expression to match filenames against.
     */
    public PatternFileFilter(String pattern) {
        this(Pattern.compile(pattern));
    }

    /** {@inheritDoc} */
    @Override
    public boolean accept(File file) {
        String filePath = file.getPath();
        boolean result = pattern.matcher(filePath).matches();
        if (LOG.isDebugEnabled()) {
            LOG.debug("pattern: {}, path: {}, result: {}", new Object[] {pattern.pattern(), filePath, result});
        }
        return result;
    }
}
