/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.jaas;

import java.io.IOException;

import javax.security.auth.callback.Callback;
import javax.security.auth.callback.CallbackHandler;
import javax.security.auth.callback.NameCallback;
import javax.security.auth.callback.PasswordCallback;
import javax.security.auth.callback.UnsupportedCallbackException;

/**
 * Proxies calls between a JAAS login module and a remote callback handler.
 */
public class RemoteCallbackHandlerAdapter implements CallbackHandler {

    private RemoteCallbackHandler remote;

    /**
     * Creates a new instance of RemoteCallbackHandlerAdapter.
     * 
     * @param remote
     *            a {@link com.squeakysand.commons.jaas.RemoteCallbackHandler} object.
     */
    public RemoteCallbackHandlerAdapter(RemoteCallbackHandler remote) {
        super();
        if (remote == null) {
            throw new IllegalArgumentException("remote cannot be null");
        }
        this.remote = remote;
    }

    /**
     *
     * @param callbacks an array of {@link javax.security.auth.callback.Callback} objects.
     * @throws java.io.IOException if any.
     * @throws javax.security.auth.callback.UnsupportedCallbackException if any.
     */
    @Override
    public void handle(Callback[] callbacks) throws IOException, UnsupportedCallbackException {
        Callback[] newCallbacks = remote.handle(callbacks);
        for (int i = 0; i < callbacks.length; i++) {
            if (callbacks[i] instanceof NameCallback) {
                ((NameCallback) callbacks[i]).setName(((NameCallback) newCallbacks[i]).getName());
            } else if (callbacks[i] instanceof PasswordCallback) {
                ((PasswordCallback) callbacks[i]).setPassword(((PasswordCallback) newCallbacks[i]).getPassword());
            } else {
                throw new UnsupportedCallbackException(callbacks[i]);
            }
        }
    }
}
