/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.jaas;

import java.io.IOException;
import java.util.Map;

import javax.security.auth.Subject;
import javax.security.auth.callback.Callback;
import javax.security.auth.callback.CallbackHandler;
import javax.security.auth.callback.NameCallback;
import javax.security.auth.callback.PasswordCallback;
import javax.security.auth.callback.UnsupportedCallbackException;
import javax.security.auth.login.FailedLoginException;
import javax.security.auth.login.LoginException;
import javax.security.auth.spi.LoginModule;

public class UsernameAndPasswordLoginModule implements LoginModule {

    private CallbackHandler handler;
    private UsernameAndPasswordPrincipal principal;
    private Subject subject;
    private boolean commitSucceeded;

    /**
     * Creates a new instance of UsernameAndPasswordLoginModule.
     */
    public UsernameAndPasswordLoginModule() {
        super();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void initialize(Subject subject, CallbackHandler handler, Map sharedMap, Map options) {
        this.subject = subject;
        this.handler = handler;
    }

    /**
     *
     * @return a boolean.
     * @throws javax.security.auth.login.LoginException if any.
     */
    @Override
    public boolean login() throws LoginException {
        NameCallback nc = new NameCallback("Username");
        PasswordCallback pc = new PasswordCallback("Password", false);
        try {
            handler.handle(new Callback[] {nc, pc});
        } catch (IOException e) {
            throw new LoginException(e.getMessage());
        } catch (UnsupportedCallbackException e) {
            throw new LoginException(e.getMessage());
        }
        if ("cdickson".equals(nc.getName()) && "dick7998".equals(new String(pc.getPassword()))) {
            principal = new UsernameAndPasswordPrincipal("cdickson");
        } else {
            throw new FailedLoginException("invalid user credentials");
        }
        return true;
    }

    /**
     *
     * @return a boolean.
     * @throws javax.security.auth.login.LoginException if any.
     */
    public boolean commit() throws LoginException {
        boolean result = false;
        if (principal != null) {
            if (!subject.getPrincipals().contains(principal)) {
                subject.getPrincipals().add(principal);
            }
            commitSucceeded = true;
            result = true;
        }
        return result;
    }

    /**
     *
     * @return a boolean.
     * @throws javax.security.auth.login.LoginException if any.
     */
    public boolean abort() throws LoginException {
        boolean result = true;
        if (principal == null) {
            result = false;
        } else if (commitSucceeded) {
            logout();
        }
        return result;
    }

    /**
     *
     * @return a boolean.
     * @throws javax.security.auth.login.LoginException if any.
     */
    public boolean logout() throws LoginException {
        subject.getPrincipals().remove(principal);
        principal = null;
        commitSucceeded = false;
        return true;
    }
}
