/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.jaas;

import java.io.Serializable;
import java.security.Principal;

import com.squeakysand.commons.lang.HashCodeHelper;

public class UsernameAndPasswordPrincipal implements Principal, Serializable {

    private static final long serialVersionUID = -2779592964219296052L;

    private String username;

    /**
     * Creates a new instance of UsernameAndPasswordPrincipal.
     * 
     * @param username
     *            a {@link java.lang.String} object.
     */
    public UsernameAndPasswordPrincipal(String username) {
        super();
        if (username == null) {
            throw new IllegalArgumentException("username cannot be null");
        }
        this.username = username;
    }

    /** {@inheritDoc} */
    @Override
    public String getName() {
        return username;
    }

    /** {@inheritDoc} */
    @Override
    public boolean equals(Object obj) {
        boolean result = false;
        if (obj instanceof UsernameAndPasswordPrincipal) {
            result = username.equals(((UsernameAndPasswordPrincipal) obj).username);
        }
        return result;
    }

    @Override
    public int hashCode() {
        return HashCodeHelper.hashCode(username);
    }

}
