/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.primarykeys;

import java.io.Serializable;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Parent class for all objects representing unique primary keys.
 * @param <T>
 */
public abstract class AbstractPrimaryKey<T> implements Serializable, Cloneable, Comparable<T> {

    private static final Logger LOG = LoggerFactory.getLogger(AbstractPrimaryKey.class);
    private static final long serialVersionUID = 8373275068461738469L;

    /**
     * Constructor for use during serialization process only.
     */
    public AbstractPrimaryKey() {
        super();
    }

    /**
     * <p>clone.</p>
     *
     * @see java.lang.Object#clone()
     * @return a {@link java.lang.Object} object.
     */
    @Override

    public Object clone() {
        Object result = null;
        try {
            result = super.clone();
        } catch (CloneNotSupportedException e) {
            LOG.error("Object.clone() threw an unexpected exception", e);
        }
        return result;
    }
}
