/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.search;

/**
 * Thrown to indicate that the {@link SearchCriteria} object that was passed to a finder method was
 * invalid.
 */
public class InvalidSearchCriteriaException extends Exception {

    private static final long serialVersionUID = 8020157329047074605L;

    private final SearchCriteria invalidCriteria;

    /**
     * Creates a new InvalidSearchCriteriaException object.
     *
     * @param  invalidCriteria the criteria that was determined to be invalid.
     * @throws java.lang.IllegalArgumentException if <code>invalidCriteria</code> is <code>null</code>.
     */
    public InvalidSearchCriteriaException(SearchCriteria invalidCriteria) {
        super();
        if (invalidCriteria == null) {
            throw new IllegalArgumentException("invalidCriteria cannot be null");
        }
        this.invalidCriteria = invalidCriteria;
    }

    /**
     * Accessor for the invalidCriteria property.
     *
     * @return the criteria that was determined to be invalid.
     */
    public SearchCriteria getInvalidCriteria() {
        return invalidCriteria;
    }
}
