/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.util;

import java.util.AbstractMap.SimpleEntry;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Dictionary;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

public class DictionaryMap<K,V> extends Dictionary<K,V> implements Map<K,V> {

    private Dictionary<K,V> dictionary;

    public DictionaryMap(Dictionary<K,V> dictionary) {
        this.dictionary = dictionary;
    }

    @Override
    public int size() {
        return dictionary.size();
    }

    @Override
    public boolean isEmpty() {
        return dictionary.isEmpty();
    }

    @Override
    public boolean containsKey(Object o) {
        Set<K> keySet = keySet();
        return keySet.contains(o);
    }

    @Override
    public boolean containsValue(Object o) {
        Collection<V> values = values();
        return values.contains(o);
    }

    @Override
    public V get(Object o) {
        return dictionary.get(o);
    }

    @Override
    public V put(K k, V v) {
        return dictionary.put(k, v);
    }

    @Override
    public V remove(Object o) {
        return dictionary.remove(o);
    }

    @Override
    public void putAll(Map<? extends K, ? extends V> map) {
        for (Map.Entry<? extends K, ? extends V> e : map.entrySet()) {
            put(e.getKey(), e.getValue());
        }
    }

    @Override
    public void clear() {
        Set<K> keys = keySet();
        for (K key : keys) {
            dictionary.remove(key);
        }
    }

    @Override
    public Set<K> keySet() {
        Set<K> result = new TreeSet<K>();
        IterableEnumeration<K> keys = keys();
        for (K key : keys) {
            result.add(key);
        }
        return result;
    }

    @Override
    public Collection<V> values() {
        List<V> result = new ArrayList<V>();
        IterableEnumeration<V> values = elements();
        for (V value : values) {
            result.add(value);
        }
        return result;
    }

    @Override
    public Set<Entry<K,V>> entrySet() {
        Set<Entry<K,V>> result = new TreeSet<Entry<K,V>>();
        Set<K> keys = keySet();
        for (K key : keys) {
            V value = dictionary.get(key);
            Entry<K,V> entry = new SimpleEntry<K,V>(key, value);
            result.add(entry);
        }
        return result;
    }

    @Override
    public IterableEnumeration<K> keys() {
        return new IterableEnumeration<K>(dictionary.keys());
    }

    @Override
    public IterableEnumeration<V> elements() {
        return new IterableEnumeration<V>(dictionary.elements());
    }

}
