/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.util;

import java.util.Iterator;
import java.util.NoSuchElementException;

public class FilteredIterator<E> implements Iterator<E> {

    private Predicate<E> filter;
    private Iterator<E> iterator;
    private E nextElement;

    public FilteredIterator(Iterator<E> iterator, Predicate<E> filter) {
        super();
        this.filter = filter;
        this.iterator = iterator;
        nextElement = getFilteredNext();
    }

    @Override
    public boolean hasNext() {
        return nextElement != null;
    }

    @Override
    public E next() {
        if (nextElement == null) {
            throw new NoSuchElementException();
        } else {
            E result = nextElement;
            nextElement = getFilteredNext();
            return result;
        }
    }

    @Override
    public void remove() {
        iterator.remove();
    }

    private E getFilteredNext() {
        E filteredNext = null;
        while (iterator.hasNext()) {
            E element = iterator.next();
            if (filter.evaluate(element)) {
                filteredNext = element;
                break;
            }
        }
        return filteredNext;
    }

}
