/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.util;

import java.util.Collection;
import java.util.List;
import java.util.ListIterator;

public class FilteredList<E> extends FilteredCollection<E> implements List<E> {

    private List<E> source;

    public FilteredList(List<E> source, Predicate<E> filter) {
        super(source, filter);
        this.source = source;
    }

    @Override
    public void add(int index, E element) {
        if (getFilter().evaluate(element)) {
            source.add(index, element);
        }
    }

    @Override
    public boolean addAll(int i, Collection<? extends E> elements) {
        boolean result = false;
        int index = i;
        for (E element : elements) {
            if (getFilter().evaluate(element)) {
                source.add(index, element);
                index++;
                result = true;
            }
        }
        return result;
    }

    @Override
    public int indexOf(Object obj) {
        // per the JavaDocs on the Collection class, it's OK to throw a ClassCastException here
        @SuppressWarnings("unchecked") E element = (E) obj;
        int result = -1;
        if (getFilter().evaluate(element)) {
            result = source.indexOf(element);
        }
        return result;
    }

    @Override
    public int lastIndexOf(Object obj) {
        // per the JavaDocs on the Collection class, it's OK to throw a ClassCastException here
        @SuppressWarnings("unchecked") E element = (E) obj;
        int result = -1;
        if (getFilter().evaluate(element)) {
            result = source.lastIndexOf(element);
        }
        return result;
    }

    @Override
    public ListIterator<E> listIterator() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public ListIterator<E> listIterator(int i) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public E remove(int i) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public List<E> subList(int i, int i1) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public E get(int i) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public E set(int i, E e) {
        throw new UnsupportedOperationException("Not supported yet.");
    }
}
