/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.xml;

import javax.xml.stream.XMLStreamConstants;
import javax.xml.stream.events.Characters;
import javax.xml.stream.events.EndElement;
import javax.xml.stream.events.StartElement;
import javax.xml.stream.events.XMLEvent;

public class DetailedXmlEventHandler implements XmlEventHandler {

    @Override
    public void handleEvent(XMLEvent event) {
        switch (event.getEventType()) {
            case XMLStreamConstants.START_DOCUMENT :
                startDocument();
                break;
            case XMLStreamConstants.END_DOCUMENT :
                endDocument();
                break;
            case XMLStreamConstants.START_ELEMENT :
                StartElement startElement = event.asStartElement();
                startElement(startElement);
                break;
            case XMLStreamConstants.END_ELEMENT :
                EndElement endElement = event.asEndElement();
                endElement(endElement);
                break;
            case XMLStreamConstants.ATTRIBUTE :
                break;
            case XMLStreamConstants.CHARACTERS :
                Characters characters = event.asCharacters();
                characters(characters);
                break;
            case XMLStreamConstants.ENTITY_REFERENCE :
                break;
            case XMLStreamConstants.NAMESPACE :
                break;
            case XMLStreamConstants.PROCESSING_INSTRUCTION :
                break;
            default :
                throw new IllegalStateException("unknown xml event type: " + event.getEventType());
        }
    }

    public void startDocument() {
    }

    public void endDocument() {
    }

    public void startElement(StartElement startElement) {
    }

    public void endElement(EndElement endElement) {
    }

    public void characters(Characters characters) {
    }
}
