/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.xml;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXParseException;

/**
 * <p>LoggingErrorHandler class.</p>
 */
public class LoggingErrorHandler implements ErrorHandler {

    private Logger logger;

    /**
     * <p>Constructor for LoggingErrorHandler.</p>
     */
    public LoggingErrorHandler() {
        logger = LoggerFactory.getLogger(LoggingErrorHandler.class);
    }

    public LoggingErrorHandler(Logger logger) {
        this.logger = logger;
    }

    /**
     * <p>Getter for the field <code>logger</code>.</p>
     *
     * @return a {@link java.util.logging.Logger} object.
     */
    public Logger getLogger() {
        return logger;
    }

    /**
     * <p>Setter for the field <code>logger</code>.</p>
     *
     * @param logger a {@link java.util.logging.Logger} object.
     */
    public void setLogger(Logger logger) {
        this.logger = logger;
    }

    /** {@inheritDoc} */
    @Override
    public void warning(SAXParseException exception) {
        logger.info("warning - exception : {}", exception);
    }

    /** {@inheritDoc} */
    @Override
    public void error(SAXParseException exception) {
        logger.info("error - exception : {}", exception);
    }

    /** {@inheritDoc} */
    @Override
    public void fatalError(SAXParseException exception) {
        logger.info("fatalError - exception : {}", exception);
    }
}
