/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.commons.xml;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

import javax.xml.stream.XMLEventReader;
import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.events.XMLEvent;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author <a href="http://craigsdickson.com">Craig S. Dickson</a>
 */
public final class StaxHelper {

    private static final Logger LOG = LoggerFactory.getLogger(StaxHelper.class);

    public static XMLEventReader getXmlEventReader(URL xmlSourceUrl) throws XmlProcessingException {
        if (xmlSourceUrl == null) {
            throw new IllegalArgumentException("xmlSourceUrl cannot be null");
        }
        XMLEventReader eventReader = null;
        XMLInputFactory factory = XMLInputFactory.newInstance();
        InputStream inputStream = null;
        try {
            inputStream = xmlSourceUrl.openStream();
            eventReader = factory.createXMLEventReader(inputStream);
        } catch (IOException e) {
            throw new XmlProcessingException(e);
        } catch (XMLStreamException e) {
            throw new XmlProcessingException(e);
        } finally {
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    LOG.warn(e.getMessage(), e);
                }
            }
        }
        return eventReader;
    }

    public static void parse(URL xmlUrlSource, XmlEventHandler eventHandler) throws XmlProcessingException {
        XMLEventReader xmlEventReader = getXmlEventReader(xmlUrlSource);
        while (xmlEventReader.hasNext()) {
            XMLEvent event = null;
            try {
                event = xmlEventReader.nextEvent();
            } catch (XMLStreamException e) {
                throw new XmlProcessingException(e);
            }
            eventHandler.handleEvent(event);
        }
    }

    private StaxHelper() {
    }

}
